# SideeX WebService API for Python
SideeX WebService Client API primarily handles the transfer of test suites to a hosted [SideeX WebService](https://hackmd.io/@sideex/webservice) server and returns the test reports.

See this [document](https://hackmd.io/@sideex/webservice-client-python-api) for more information.